==> mutt-language-server-0.0.1.tar.gz: mutt-language-server-0.0.1/README.md <==
# mutt-language-server

[![readthedocs](https://shields.io/readthedocs/mutt-language-server)](https://mutt-language-server.readthedocs.io)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/Freed-Wu/mutt-language-server/main.svg)](https://results.pre-commit.ci/latest/github/Freed-Wu/mutt-language-server/main)
[![github/workflow](https://github.com/Freed-Wu/mutt-language-server/actions/workflows/main.yml/badge.svg)](https://github.com/Freed-Wu/mutt-language-server/actions)
[![codecov](https://codecov.io/gh/Freed-Wu/mutt-language-server/branch/main/graph/badge.svg)](https://codecov.io/gh/Freed-Wu/mutt-language-server)
[![DeepSource](https://deepsource.io/gh/Freed-Wu/mutt-language-server.svg/?show_trend=true)](https://deepsource.io/gh/Freed-Wu/mutt-language-server)

[![github/downloads](https://shields.io/github/downloads/Freed-Wu/mutt-language-server/total)](https://github.com/Freed-Wu/mutt-language-server/releases)
[![github/downloads/latest](https://shields.io/github/downloads/Freed-Wu/mutt-language-server/latest/total)](https://github.com/Freed-Wu/mutt-language-server/releases/latest)
[![github/issues](https://shields.io/github/issues/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/issues)
[![github/issues-closed](https://shields.io/github/issues-closed/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/issues?q=is%3Aissue+is%3Aclosed)
[![github/issues-pr](https://shields.io/github/issues-pr/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/pulls)
[![github/issues-pr-closed](https://shields.io/github/issues-pr-closed/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/pulls?q=is%3Apr+is%3Aclosed)
[![github/discussions](https://shields.io/github/discussions/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/discussions)
[![github/milestones](https://shields.io/github/milestones/all/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/milestones)
[![github/forks](https://shields.io/github/forks/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/network/members)
[![github/stars](https://shields.io/github/stars/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/stargazers)
[![github/watchers](https://shields.io/github/watchers/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/watchers)
[![github/contributors](https://shields.io/github/contributors/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/graphs/contributors)
[![github/commit-activity](https://shields.io/github/commit-activity/w/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/graphs/commit-activity)
[![github/last-commit](https://shields.io/github/last-commit/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/commits)
[![github/release-date](https://shields.io/github/release-date/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/releases/latest)

[![github/license](https://shields.io/github/license/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/blob/main/LICENSE)
[![github/languages](https://shields.io/github/languages/count/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server)
[![github/languages/top](https://shields.io/github/languages/top/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server)
[![github/directory-file-count](https://shields.io/github/directory-file-count/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server)
[![github/code-size](https://shields.io/github/languages/code-size/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server)
[![github/repo-size](https://shields.io/github/repo-size/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server)
[![github/v](https://shields.io/github/v/release/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server)

[![pypi/status](https://shields.io/pypi/status/mutt-language-server)](https://pypi.org/project/mutt-language-server/#description)
[![pypi/v](https://shields.io/pypi/v/mutt-language-server)](https://pypi.org/project/mutt-language-server/#history)
[![pypi/downloads](https://shields.io/pypi/dd/mutt-language-server)](https://pypi.org/project/mutt-language-server/#files)
[![pypi/format](https://shields.io/pypi/format/mutt-language-server)](https://pypi.org/project/mutt-language-server/#files)
[![pypi/implementation](https://shields.io/pypi/implementation/mutt-language-server)](https://pypi.org/project/mutt-language-server/#files)
[![pypi/pyversions](https://shields.io/pypi/pyversions/mutt-language-server)](https://pypi.org/project/mutt-language-server/#files)

A language server for (neo)mutt's muttrc.

- [x] document hover
- [x] completion

![Document hover](https://github.com/Freed-Wu/mutt-language-server/assets/32936898/80f19981-17e6-47a1-86a7-f29f8f3f99ab)

![Completion](https://github.com/Freed-Wu/mutt-language-server/assets/32936898/b604d659-4c97-4b3c-887f-7530fcb53a46)

See
[![readthedocs](https://shields.io/readthedocs/mutt-language-server)](https://mutt-language-server.readthedocs.io)
to know more.

==> mutt-language-server-0.0.2.tar.gz: mutt-language-server-0.0.2/README.md <==
# mutt-language-server

[![readthedocs](https://shields.io/readthedocs/mutt-language-server)](https://mutt-language-server.readthedocs.io)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/Freed-Wu/mutt-language-server/main.svg)](https://results.pre-commit.ci/latest/github/Freed-Wu/mutt-language-server/main)
[![github/workflow](https://github.com/Freed-Wu/mutt-language-server/actions/workflows/main.yml/badge.svg)](https://github.com/Freed-Wu/mutt-language-server/actions)
[![codecov](https://codecov.io/gh/Freed-Wu/mutt-language-server/branch/main/graph/badge.svg)](https://codecov.io/gh/Freed-Wu/mutt-language-server)
[![DeepSource](https://deepsource.io/gh/Freed-Wu/mutt-language-server.svg/?show_trend=true)](https://deepsource.io/gh/Freed-Wu/mutt-language-server)

[![github/downloads](https://shields.io/github/downloads/Freed-Wu/mutt-language-server/total)](https://github.com/Freed-Wu/mutt-language-server/releases)
[![github/downloads/latest](https://shields.io/github/downloads/Freed-Wu/mutt-language-server/latest/total)](https://github.com/Freed-Wu/mutt-language-server/releases/latest)
[![github/issues](https://shields.io/github/issues/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/issues)
[![github/issues-closed](https://shields.io/github/issues-closed/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/issues?q=is%3Aissue+is%3Aclosed)
[![github/issues-pr](https://shields.io/github/issues-pr/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/pulls)
[![github/issues-pr-closed](https://shields.io/github/issues-pr-closed/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/pulls?q=is%3Apr+is%3Aclosed)
[![github/discussions](https://shields.io/github/discussions/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/discussions)
[![github/milestones](https://shields.io/github/milestones/all/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/milestones)
[![github/forks](https://shields.io/github/forks/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/network/members)
[![github/stars](https://shields.io/github/stars/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/stargazers)
[![github/watchers](https://shields.io/github/watchers/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/watchers)
[![github/contributors](https://shields.io/github/contributors/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/graphs/contributors)
[![github/commit-activity](https://shields.io/github/commit-activity/w/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/graphs/commit-activity)
[![github/last-commit](https://shields.io/github/last-commit/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/commits)
[![github/release-date](https://shields.io/github/release-date/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/releases/latest)

[![github/license](https://shields.io/github/license/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server/blob/main/LICENSE)
[![github/languages](https://shields.io/github/languages/count/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server)
[![github/languages/top](https://shields.io/github/languages/top/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server)
[![github/directory-file-count](https://shields.io/github/directory-file-count/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server)
[![github/code-size](https://shields.io/github/languages/code-size/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server)
[![github/repo-size](https://shields.io/github/repo-size/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server)
[![github/v](https://shields.io/github/v/release/Freed-Wu/mutt-language-server)](https://github.com/Freed-Wu/mutt-language-server)

[![pypi/status](https://shields.io/pypi/status/mutt-language-server)](https://pypi.org/project/mutt-language-server/#description)
[![pypi/v](https://shields.io/pypi/v/mutt-language-server)](https://pypi.org/project/mutt-language-server/#history)
[![pypi/downloads](https://shields.io/pypi/dd/mutt-language-server)](https://pypi.org/project/mutt-language-server/#files)
[![pypi/format](https://shields.io/pypi/format/mutt-language-server)](https://pypi.org/project/mutt-language-server/#files)
[![pypi/implementation](https://shields.io/pypi/implementation/mutt-language-server)](https://pypi.org/project/mutt-language-server/#files)
[![pypi/pyversions](https://shields.io/pypi/pyversions/mutt-language-server)](https://pypi.org/project/mutt-language-server/#files)

A language server for (neo)mutt's muttrc.

- [x] document hover
- [x] completion

![Document hover](https://github.com/Freed-Wu/mutt-language-server/assets/32936898/e8da8c8b-62e6-403a-b8d2-ef5dee29a480)

![Completion](https://github.com/Freed-Wu/mutt-language-server/assets/32936898/7bfe3145-775d-4767-8d0e-e7b082e39d2e)

See
[![readthedocs](https://shields.io/readthedocs/mutt-language-server)](https://mutt-language-server.readthedocs.io)
to know more.
